export declare enum BackgroundToolType {
    SHELL = "shell",
    BROWSER = "browser",
    AGENT = "agent"
}
export declare enum BackgroundToolStatus {
    RUNNING = "running",
    COMPLETED = "completed",
    ERROR = "error",
    TERMINATED = "terminated"
}
export interface BackgroundTool {
    id: string;
    type: BackgroundToolType;
    status: BackgroundToolStatus;
    startTime: Date;
    endTime?: Date;
    agentId: string;
    metadata: Record<string, any>;
}
export interface ShellBackgroundTool extends BackgroundTool {
    type: BackgroundToolType.SHELL;
    metadata: {
        command: string;
        exitCode?: number | null;
        signaled?: boolean;
    };
}
export interface BrowserBackgroundTool extends BackgroundTool {
    type: BackgroundToolType.BROWSER;
    metadata: {
        url?: string;
    };
}
export interface AgentBackgroundTool extends BackgroundTool {
    type: BackgroundToolType.AGENT;
    metadata: {
        goal?: string;
    };
}
export type AnyBackgroundTool = ShellBackgroundTool | BrowserBackgroundTool | AgentBackgroundTool;
/**
 * Registry to keep track of all background processes
 */
export declare class BackgroundToolRegistry {
    private static instance;
    private tools;
    private constructor();
    static getInstance(): BackgroundToolRegistry;
    registerShell(agentId: string, command: string): string;
    registerBrowser(agentId: string, url?: string): string;
    registerAgent(agentId: string, goal?: string): string;
    updateToolStatus(id: string, status: BackgroundToolStatus, metadata?: Record<string, any>): boolean;
    getToolsByAgent(agentId: string): AnyBackgroundTool[];
    getToolById(id: string): AnyBackgroundTool | undefined;
    cleanupOldTools(olderThanHours?: number): void;
}
export declare const backgroundToolRegistry: BackgroundToolRegistry;
//# sourceMappingURL=backgroundTools.d.ts.map